# ml_belt
the machine learning utility belt

https://pypi.org/project/ml_belt/


## Instalation
You can install using pip:

    pip install ml_belt

## Usage
```python
import ml_belt as mlb

...

df = mlb.create_dummies(df, columns)
